@@ -10,7 +10,6 @@
 
 #include "kmimetypefactory_p.h"
 #include "kservicefactory_p.h"
-#include "kservicetypefactory_p.h"
 #include "ksycoca.h"
 #include "ksycoca_p.h"
 #include "servicesdebug.h"
@@ -36,9 +35,7 @@ static KService::List mimeTypeSycocaServiceOffers(const QString &mimeType)
     KMimeTypeFactory *factory = KSycocaPrivate::self()->mimeTypeFactory();
     const int offset = factory->entryOffset(mime);
     if (!offset) {
-        if (!mimeType.startsWith(QLatin1String("x-scheme-handler/"))) { // don't warn for unknown scheme handler mimetypes
-            qCWarning(SERVICES) << "KApplicationTrader: mimeType" << mimeType << "not found";
-        }
+        qCWarning(SERVICES) << "KApplicationTrader: mimeType" << mimeType << "not found";
         return lst; // empty
     }
     const int serviceOffersOffset = factory->serviceOffersOffset(mime);
@@ -48,22 +45,6 @@ static KService::List mimeTypeSycocaServiceOffers(const QString &mimeType)
     return lst;
 }
 
-// Filter the offers for the requested MIME type in order to keep only applications.
-static void filterMimeTypeOffers(KService::List &list) // static, internal
-{
-    KServiceType::Ptr genericServiceTypePtr = KServiceType::serviceType(QStringLiteral("Application"));
-    Q_ASSERT(genericServiceTypePtr);
-
-    KSycoca::self()->ensureCacheValid();
-    KServiceFactory *serviceFactory = KSycocaPrivate::self()->serviceFactory();
-
-    // Remove non-Applications (TODO KF6: kill plugin desktop files, then kill this code)
-    auto removeFunc = [&](const KService::Ptr &serv) {
-        return !serviceFactory->hasOffer(genericServiceTypePtr, serv);
-    };
-    list.erase(std::remove_if(list.begin(), list.end(), removeFunc), list.end());
-}
-
 static void applyFilter(KService::List &list, KApplicationTrader::FilterFunc filterFunc, bool mustShowInCurrentDesktop)
 {
     if (list.isEmpty()) {
@@ -82,13 +63,7 @@ KService::List KApplicationTrader::query(FilterFunc filterFunc)
 {
     // Get all applications
     KSycoca::self()->ensureCacheValid();
-    KServiceType::Ptr servTypePtr = KSycocaPrivate::self()->serviceTypeFactory()->findServiceTypeByName(QStringLiteral("Application"));
-    Q_ASSERT(servTypePtr);
-    if (servTypePtr->serviceOffersOffset() == -1) {
-        return KService::List();
-    }
-
-    KService::List lst = KSycocaPrivate::self()->serviceFactory()->serviceOffers(servTypePtr);
+    KService::List lst = KSycocaPrivate::self()->serviceFactory()->allServices();
 
     applyFilter(lst, filterFunc, true); // true = filter out service with NotShowIn=KDE or equivalent
 
@@ -100,7 +75,6 @@ KService::List KApplicationTrader::queryByMimeType(const QString &mimeType, Filt
 {
     // Get all services of this MIME type.
     KService::List lst = mimeTypeSycocaServiceOffers(mimeType);
-    filterMimeTypeOffers(lst);
 
     applyFilter(lst, filterFunc, false); // false = allow NotShowIn=KDE services listed in mimeapps.list
 
@@ -125,10 +99,10 @@ void KApplicationTrader::setPreferredService(const QString &mimeType, const KSer
     KSharedConfig::Ptr profile = KSharedConfig::openConfig(QStringLiteral("mimeapps.list"), KConfig::NoGlobals, QStandardPaths::GenericConfigLocation);
 
     // Save the default application according to mime-apps-spec 1.0
-    KConfigGroup defaultApp(profile, "Default Applications");
+    KConfigGroup defaultApp(profile, QStringLiteral("Default Applications"));
     defaultApp.writeXdgListEntry(mimeType, QStringList(service->storageId()));
 
-    KConfigGroup addedApps(profile, "Added Associations");
+    KConfigGroup addedApps(profile, QStringLiteral("Added Associations"));
     QStringList apps = addedApps.readXdgListEntry(mimeType);
     apps.removeAll(service->storageId());
     apps.prepend(service->storageId()); // make it the preferred app
@@ -138,7 +112,7 @@ void KApplicationTrader::setPreferredService(const QString &mimeType, const KSer
 
     // Also make sure the "auto embed" setting for this MIME type is off
     KSharedConfig::Ptr fileTypesConfig = KSharedConfig::openConfig(QStringLiteral("filetypesrc"), KConfig::NoGlobals);
-    fileTypesConfig->group("EmbedSettings").writeEntry(QStringLiteral("embed-") + mimeType, false);
+    fileTypesConfig->group(QStringLiteral("EmbedSettings")).writeEntry(QStringLiteral("embed-") + mimeType, false);
     fileTypesConfig->sync();
 }
 
