@@ -795,7 +795,7 @@ QStringList KService::mimeTypes() const
     return ret;
 }
 
-QStringList KService::supportedProtocols() const
+QStringList KService::schemeHandlers() const
 {
     Q_D(const KService);
 
@@ -809,6 +809,17 @@ QStringList KService::supportedProtocols() const
         }
     }
 
+    return ret;
+}
+
+QStringList KService::supportedProtocols() const
+{
+    Q_D(const KService);
+
+    QStringList ret;
+
+    ret << schemeHandlers();
+
     const QStringList protocols = property<QStringList>(QStringLiteral("X-KDE-Protocols"));
     for (const QString &protocol : protocols) {
         if (!ret.contains(protocol)) {
